Crate rs_auth_core

Crate rs_auth_core 

Core domain logic for rs-auth.

This crate contains configuration types, error definitions, store traits, the email sender trait, cryptographic helpers, and the AuthService that drives all authentication flows.

Re-exports

pub use config::AuthConfig;
pub use config::CookieConfig;
pub use config::EmailConfig;
pub use config::SameSite;
pub use error::AuthError;
pub use events::AuthEvent;
pub use events::LoginFailReason;
pub use events::LoginMethod;
pub use hooks::AuthHook;
pub use hooks::EventEmitter;
pub use rate_limit::NoOpRateLimiter;
pub use rate_limit::RateLimitAction;
pub use rate_limit::RateLimiter;
pub use service::AuthService;
pub use service::LinkAccountResult;
pub use service::LoginResult;
pub use service::RefreshTokenResult;
pub use service::RequestResetResult;
pub use service::ResetPasswordResult;
pub use service::SessionResult;
pub use service::SignupResult;
pub use service::UnlinkAccountResult;
pub use service::VerifyEmailResult;
pub use store::OAuthStateStore;
pub use types::OAuthIntent;
pub use types::PublicAccount;

Modules

config
crypto
email
error
events
hooks
oauth
rate_limit
service
store
types