Crate rs_auth_core

Crate rs_auth_core 

Core domain logic for rs-auth.

This crate contains configuration types, error definitions, store traits, the email sender trait, cryptographic helpers, and the AuthService that drives all authentication flows.

Re-exports

pub use config::AuthConfig;
pub use config::CookieConfig;
pub use config::EmailConfig;
pub use config::SameSite;
pub use error::AuthError;
pub use service::AuthService;
pub use service::LoginResult;
pub use service::RequestResetResult;
pub use service::ResetPasswordResult;
pub use service::SessionResult;
pub use service::SignupResult;
pub use service::VerifyEmailResult;

Modules

config
crypto
email
error
oauth
service
store
types