pub struct EmailConfig {
pub send_verification_on_signup: bool,
pub require_verification_to_login: bool,
pub auto_sign_in_after_signup: bool,
pub auto_sign_in_after_verification: bool,
}Expand description
Email behavior configuration.
Fields
send_verification_on_signup: boolWhether to send a verification email on signup. Default: true.
require_verification_to_login: boolWhether to require email verification before allowing login. Default: false.
auto_sign_in_after_signup: boolWhether to automatically sign in the user after signup. Default: true.
auto_sign_in_after_verification: boolWhether to automatically sign in the user after email verification. Default: false.